diff --git a/descriptions/rep/cs_cz.lua b/descriptions/rep/cs_cz.lua
index 6a2ef342..82504db2 100644
--- a/descriptions/rep/cs_cz.lua
+++ b/descriptions/rep/cs_cz.lua
@@ -1107,7 +1107,7 @@ EID.descriptions[languageCode].AchievementWarningText = "Achievementy jsou zaká
EID.descriptions[languageCode].OldGameVersionWarningText = "Tvoje verze Repentance není aktuální!#Oficiálně je podporována pouze ta nejnovější verze#(Toto varování lze vypnout v konfiguraci)"
-EID.descriptions[languageCode].ModdedRecipesWarningText = "Modované předměty by mohly způsobit nepřesnost výpočtu receptu na výrobu!#Použij režim zobrazení Žádné recepty (No Recipes) nebo vypni zobrazení u Craftovacího Pytlíku, pokud jsou tvé recepty nesprávné#(Toto varování lze deaktivovat v konfiguraci)"
+EID.descriptions[languageCode].ModdedRecipesWarningText = "Modované předměty by mohly způsobit nepřesnost výpočtu receptu na výrobu!#Použij režim zobrazení Žádné recepty (Itempool Percentages) nebo vypni zobrazení u Craftovacího Pytlíku, pokud jsou tvé recepty nesprávné#(Toto varování lze deaktivovat v konfiguraci)"
-- If Debug enabled, add overwrite tables to the languagepack in order for the language completion script to be able to compare them
diff --git a/descriptions/rep/en_us.lua b/descriptions/rep/en_us.lua
index 70aef84f..a20efe6a 100644
--- a/descriptions/rep/en_us.lua
+++ b/descriptions/rep/en_us.lua
@@ -1094,7 +1094,7 @@ EID.descriptions[languageCode].AchievementWarningText = "Achievements are disabl
EID.descriptions[languageCode].OldGameVersionWarningText = "Your version of Repentance is not up-to-date!#Only the newest version is officially supported#(This warning can be disabled in the config)"
-EID.descriptions[languageCode].ModdedRecipesWarningText = "Modded items could make the crafting recipe calculation inaccurate!#Use the No Recipes display mode or turn off the Bag of Crafting display if your recipes are incorrect#(This warning can be disabled in the config)"
+EID.descriptions[languageCode].ModdedRecipesWarningText = "Modded items could make the crafting recipe calculation inaccurate!#Use the Itempool Percentages display mode or turn off the Bag of Crafting display if your recipes are incorrect#(This warning can be disabled in the config)"
-- If Debug enabled, add overwrite tables to the languagepack in order for the language completion script to be able to compare them
diff --git a/descriptions/rep/ja_jp.lua b/descriptions/rep/ja_jp.lua
index 9dcc099f..c45e4bd0 100644
--- a/descriptions/rep/ja_jp.lua
+++ b/descriptions/rep/ja_jp.lua
@@ -1098,7 +1098,7 @@ EID.descriptions[languageCode].AchievementWarningText = "実績無効!#実績
EID.descriptions[languageCode].OldGameVersionWarningText = "ゲームがアップデート されていません#最新バージョンのみが サポートされています#この警告は設定で無効に できます"
-EID.descriptions[languageCode].ModdedRecipesWarningText = "MODのアイテムが原因で クラフトレシピの表示が 不正確になる可能性が あります#その場合、No Recipes モードか、非表示にして ください#この警告は設定で無効に できます"
+EID.descriptions[languageCode].ModdedRecipesWarningText = "MODのアイテムが原因で クラフトレシピの表示が 不正確になる可能性が あります#その場合、Itempool Percentages モードか、非表示にして ください#この警告は設定で無効に できます"
-- If Debug enabled, add overwrite tables to the languagepack in order for the language completion script to be able to compare them
diff --git a/descriptions/rep/ru.lua b/descriptions/rep/ru.lua
index b639c290..ea9a16f1 100644
--- a/descriptions/rep/ru.lua
+++ b/descriptions/rep/ru.lua
@@ -1084,7 +1084,7 @@ EID.descriptions[languageCode].AchievementWarningText = "Достижения о
EID.descriptions[languageCode].OldGameVersionWarningText = "Ваша версия Repentance не обновлена!#Только самая последняя версия официально поддерживается#(Это предупреждение можно выключить в конфиге)"
-EID.descriptions[languageCode].ModdedRecipesWarningText = "Предметы из модов могут сделать расчёт крафтов неточным!#Используйте режим отображения \"No Recipes\" или отключите отображение Крафт-Мешка, если ваши рецепты неверны#(Это предупреждение можно выключить в конфиге)"
+EID.descriptions[languageCode].ModdedRecipesWarningText = "Предметы из модов могут сделать расчёт крафтов неточным!#Используйте режим отображения \"Itempool Percentages\" или отключите отображение Крафт-Мешка, если ваши рецепты неверны#(Это предупреждение можно выключить в конфиге)"
-- If Debug enabled, add overwrite tables to the languagepack in order for the language completion script to be able to compare them
diff --git a/descriptions/rep/spa.lua b/descriptions/rep/spa.lua
index 9ae513f8..57316b96 100644
--- a/descriptions/rep/spa.lua
+++ b/descriptions/rep/spa.lua
@@ -1111,7 +1111,7 @@ EID.descriptions[languageCode].AchievementWarningTitle = "{{ColorYellow}}!!! ADV
EID.descriptions[languageCode].AchievementWarningText = "¡Los logros están deshabilitados!#Para poder progresar en el juego, primero debes vencer a Mamá (Depths II) sin mods habilitados.#(Si ya derrotaste a Mamá, este mensaje es un bug, ignóralo)#(Este aviso puede ser desactivado en la configuración)"
EID.descriptions[languageCode].OutdatedModWarningText = "¡Un mod sin actualizar está reduciendo la cantidad de objetos! Esto puede causar crasheos, especialmente al entrar al area de la Pieza del cuchillo 2#Por favor, desinstala los mods con el archivo resources/items.xml desactualizado"
EID.descriptions[languageCode].OldGameVersionWarningText = "Tu versión de Repentance no es la más reciente#La versión más reciente es la única con soporte oficial#(Este aviso puede ser desactivado en la configuración)"
-EID.descriptions[languageCode].ModdedRecipesWarningText = "Los objetos modeados pueden provocar cálculos incorrectos#Usa el modo No Recipes o desactiva el cálculo de la Bolsa de trabajo si es que los cálculos son incorrectos#(Este aviso puede ser desactivado en la configuración)"
+EID.descriptions[languageCode].ModdedRecipesWarningText = "Los objetos modeados pueden provocar cálculos incorrectos#Usa el modo Itempool Percentages o desactiva el cálculo de la Bolsa de trabajo si es que los cálculos son incorrectos#(Este aviso puede ser desactivado en la configuración)"
-- Warnings end
-- False PHD modifier
diff --git a/eid_config.lua b/eid_config.lua
index b41772ab..82a36f54 100644
--- a/eid_config.lua
+++ b/eid_config.lua
@@ -339,14 +339,14 @@ EID.UserConfig = {
-- Default = "always"
["DisplayBagOfCrafting"] = "always",
-- Display modes for the Bag of Crafting display
- -- Options: "Recipe List", "Preview Only", "No Recipes", "Pickups Only"
- -- The recipe list is a detailed calculated list of recipes based on what you have available on the floor
- -- Preview Only shows the description of the item you can currently craft in your bag
- -- No Recipes shows percentages of what item you might get from your bag / best option on the floor, for a more intended experience
- -- Pickups Only just shows the room/floor pickup count
- -- (No Recipes is recommended if you have modded items)
+ -- Options: "Recipe List", "Preview Only", "Itempool Percentages", "Pickups Only"
+ -- The "Recipe List" is a detailed calculated list of recipes based on what you have available on the floor
+ -- "Preview Only" shows the description of the item you can currently craft in your bag
+ -- "Itempool Percentages" shows percentages of what item you might get from your bag / best option on the floor, for a more intended experience
+ -- "Pickups Only" just shows the room/floor pickup count
+ -- ("Itempool Percentages" is recommended if you have modded items)
-- Default = "Recipe List"
- ["BagOfCraftingDisplayMode"] = "Recipe List",
+ ["BagOfCraftingDisplayRecipesMode"] = "Recipe List",
-- Hide the recipe list when in battle
-- Default = true
["BagOfCraftingHideInBattle"] = true,
@@ -545,7 +545,7 @@ EID.DefaultConfig = {
["BagOfCraftingDisplayIcons"] = false,
["BagOfCraftingHideInBattle"] = true,
["BagOfCraftingShowControls"] = true,
- ["BagOfCraftingDisplayMode"] = "Recipe List",
+ ["BagOfCraftingDisplayRecipesMode"] = "Recipe List",
["BagOfCraftingModdedRecipes"] = true,
["CraftingHideKey"] = Keyboard.KEY_F3,
["CraftingHideButton"] = -1,
diff --git a/eid_mcm.lua b/eid_mcm.lua
index 8db1c7a1..8e02fcfa 100644
--- a/eid_mcm.lua
+++ b/eid_mcm.lua
@@ -602,8 +602,8 @@ if MCMLoaded then
EID:AddNumberSetting("Crafting", "DisplayBagOfCrafting", "Show Display", 1, #bagDisplays, { displayingTab = "Crafting", indexOf = bagDisplays, infoText = {"Always = Always show Results", "Hold = Show when holding up bag", "Never = Disable Bag of Crafting feature"}})
-- Bag of Crafting Display Mode
- local bagDisplayModes = {"Recipe List","Preview Only","No Recipes","Pickups Only"}
- EID:AddNumberSetting("Crafting", "BagOfCraftingDisplayMode", "Display Mode", 1, #bagDisplayModes, { indexOf = bagDisplayModes,
+ local bagDisplayModes = {"Recipe List","Preview Only","Itempool Percentages","Pickups Only"}
+ EID:AddNumberSetting("Crafting", "BagOfCraftingDisplayRecipesMode", "Display Mode", 1, #bagDisplayModes, { indexOf = bagDisplayModes,
infoText = {"Toggle showing a list of recipes, an item preview when bag is full, what item pool/quality you might get, or only the floor pickups"}})
-- Bag of Crafting Hide in Battle
@@ -615,7 +615,7 @@ if MCMLoaded then
-- Bag of Crafting 8 icons toggle
EID:AddBooleanSetting("Crafting", "BagOfCraftingDisplayIcons", "Show Recipes/Best Bag as", {onText = "8 Icons", offText = "Groups",
- infoText = "Choose if you want recipes (and the Best Quality bag in No Recipes Mode) shown as 8 icons, or as grouped ingredients"})
+ infoText = "Choose if you want recipes (and the Best Quality bag in Itempool Percentages Mode) shown as 8 icons, or as grouped ingredients"})
-- Modded Recipes toggle
EID:AddBooleanSetting("Crafting", "BagOfCraftingModdedRecipes", "Load Modded Item Recipes (WIP)", {
infoText = {"Enable or disable basic modded item support", "If you have a lot of modded items, it will slow down game launch"}})
diff --git a/eid_mcm_cn.lua b/eid_mcm_cn.lua
index 4aa7fc6a..3c78bd34 100644
--- a/eid_mcm_cn.lua
+++ b/eid_mcm_cn.lua
@@ -209,7 +209,7 @@ if MCMLoaded and MCM and MCM.i18n == "Chinese" then
{"Displayed Recipes","配方显示数量"},
{"Hide in Battle","战斗时隐藏"},
{"Pickups Only","仅掉落物"},
- {"No Recipes","无配方"},
+ {"Itempool Percentages","物品池百分比"},
{"Show Recipes/Best Bag as","配方/最佳组合显示方式"},
{"8 Icons","8图标"},
{"Groups","分组"},
@@ -402,8 +402,8 @@ if MCMLoaded and MCM and MCM.i18n == "Chinese" then
= "切换显示配方列表,袋满时的道具预览,道具池/品质信息,或地面上的掉落物",
["Hides the Bag of Crafting info when in a fight"] = "在战斗中隐藏合成宝袋信息",
["Show the text for the Hide/Preview and Recipe List hotkeys"] = "显示切换隐藏/预览和配方列表的热键",
- ["Choose if you want recipes (and the Best Quality bag in No Recipes Mode) shown as 8 icons, or as grouped ingredients"]
- = "切换配方显示模式(或无配方模式下的最佳品质)为8个图标,或者分组显示",
+ ["Choose if you want recipes (and the Best Quality bag in Itempool Percentages Mode) shown as 8 icons, or as grouped ingredients"]
+ = "切换配方显示模式(或无配方模式下的最佳品质)为8个图标, 或者分组显示",
["Enable or disable basic modded item support"] = "开关基础的模组道具支持",
["If you have a lot of modded items, it will slow down game launch"] = "如果模组道具太多,游戏会变卡",
["(12 = 500 combinations, 14 = 3,000, 16 = 13,000)"] = "(12=500组合,14=3000,16=13000)",
@@ -417,7 +417,7 @@ if MCMLoaded and MCM and MCM.i18n == "Chinese" then
= "如果开启,每个配方会显示两行,第一行是名字,第二行是配方",
["Press this to clear all currently detected items on the floor"] = "按此键清除所有当前房间中已检测的物品",
["Press this to clear all currently detected items on the bag"] = "按此键清除所有当前袋中已检测的物品",
- ["Choose if you want recipes (and the Best Quality bag in No Recipes Mode) shown as 8 icons, or as grouped ingredients"]
+ ["Choose if you want recipes (and the Best Quality bag in Itempool Percentages Mode) shown as 8 icons, or as grouped ingredients"]
= "选择使用八个图标还是分组 显示配方(或无配方模式的最佳组合)",
["Press this key to toggle the crafting display, allowing you to check descriptions of items/pickups on the floor"]
= "按此键切换合成袋的显示,以预览地面上的道具/掉落物描述",
diff --git a/main.lua b/main.lua
index 4f31297c..7bccbe85 100644
--- a/main.lua
+++ b/main.lua
@@ -9,7 +9,7 @@ local game = Game()
require("eid_config")
EID.Config = EID.UserConfig
EID.Config.Version = "3.2" -- note: changing this will reset everyone's settings to default!
-EID.ModVersion = "4.41"
+EID.ModVersion = "4.42"
EID.DefaultConfig.Version = EID.Config.Version
EID.isHidden = false
EID.player = nil -- The primary Player Entity of Player 1
@@ -1084,7 +1084,7 @@ local function checkStartOfRunWarnings()
hasShownStartWarning = true
-- Bag of Crafting modded items check
elseif EID:PlayersHaveCollectible(710) and EID:DetectModdedItems() and EID.Config.DisplayBagOfCrafting ~= "never" and
- (EID.Config.BagOfCraftingDisplayMode == "Recipe List" or EID.Config.BagOfCraftingDisplayMode == "Preview Only") then
+ (EID.Config.BagOfCraftingDisplayRecipesMode == "Recipe List" or EID.Config.BagOfCraftingDisplayRecipesMode == "Preview Only") then
local demoDescObj = EID:getDescriptionObj(-999, -1, 1)
demoDescObj.Name = EID:getDescriptionEntry("AchievementWarningTitle") or ""
demoDescObj.Description = EID:getDescriptionEntry("ModdedRecipesWarningText") or ""
diff --git a/metadata.xml b/metadata.xml
index 1400d653..fd075306 100644
--- a/metadata.xml
+++ b/metadata.xml
@@ -114,7 +114,7 @@ https://moddingofisaac.com/mod/1079/external-item-descriptions
- prefab for the incredible [b]Japanese[/b] language pack
- David Kapitančik. Picus and domcizzz for the cool [b]Czech[/b] language pack
- [url=https://steamcommunity.com/id/whytefang/]adc[/url] for creating an awesome new Languagepack and providing ideas for new functionalities
- 4.41
+ 4.42
Public
diff --git a/eid_bagofcrafting.lua b/eid_bagofcrafting.lua
index 7002e245..5ad4db0e 100644
--- a/eid_bagofcrafting.lua
+++ b/eid_bagofcrafting.lua
@@ -184,7 +184,7 @@ local componentShifts = {
{0x00000011, 0x0000000F, 0x0000001A}
}
--- The icon each item pool will use in the No Recipes display
+-- The icon each item pool will use in the "Itempool Percentages" display
local poolToIcon = { [0]="{{TreasureRoom}}",[1]="{{Shop}}",[2]="{{BossRoom}}",[3]="{{DevilRoom}}",[4]="{{AngelRoom}}",
[5]="{{SecretRoom}}",[7]="{{PoopRoomIcon}}",[8]="{{GoldenChestRoomIcon}}",[9]="{{RedChestRoomIcon}}",[12]="{{CursedRoom}}",[26]="{{Planetarium}}" }
@@ -269,7 +269,7 @@ function EID:getBagOfCraftingID(Variant, SubType)
return nil
end
--- NO RECIPES MODE: Get percentages of what quality / item pool a given set of 8 ingredients can yield
+-- "Itempool Percentages" MODE: Get percentages of what quality / item pool a given set of 8 ingredients can yield
function EID:simulateBagOfCrafting(componentsTable)
local components = componentsTable
local compTotalWeight = 0
@@ -751,7 +751,7 @@ local function getHotkeyString()
hotkeyString = hotkeyString .. (hideKey or hideButton)
end
- if #EID.BoC.BagItems >= 8 and EID.Config["BagOfCraftingDisplayMode"] ~= "Preview Only" then
+ if #EID.BoC.BagItems >= 8 and EID.Config["BagOfCraftingDisplayRecipesMode"] ~= "Preview Only" then
if previewKey or previewButton then hotkeyString = hotkeyString .. ", " .. previewDesc .. " " end
if previewKey and previewButton then
hotkeyString = hotkeyString .. previewKey .. "/" .. previewButton
@@ -986,8 +986,8 @@ function EID:handleBagOfCraftingRendering(ignoreRefreshRate)
local bagItems = EID.BoC.BagItemsOverride or EID.BoC.BagItems
-- Display the result of the 8 items in our bag if applicable
- if (showCraftingResult or EID.Config["BagOfCraftingDisplayMode"] == "Preview Only") and #bagItems == 8 then
- if EID.Config["BagOfCraftingDisplayMode"] ~= "Recipe List" and EID:hasCurseBlind() and EID.Config["DisableOnCurse"] then
+ if (showCraftingResult or EID.Config["BagOfCraftingDisplayRecipesMode"] == "Preview Only") and #bagItems == 8 then
+ if EID.Config["BagOfCraftingDisplayRecipesMode"] ~= "Recipe List" and EID:hasCurseBlind() and EID.Config["DisableOnCurse"] then
showCraftingResult = false
return false
end
@@ -1007,7 +1007,7 @@ function EID:handleBagOfCraftingRendering(ignoreRefreshRate)
return true
end
-- if we're in Preview Only mode, then we have nothing more to do
- if (EID.Config["BagOfCraftingDisplayMode"] == "Preview Only") then return false end
+ if (EID.Config["BagOfCraftingDisplayRecipesMode"] == "Preview Only") then return false end
-- Check what pickups are available in this room
local curRoomIndex = game:GetLevel():GetCurrentRoomDesc().ListIndex
@@ -1068,13 +1068,13 @@ function EID:handleBagOfCraftingRendering(ignoreRefreshRate)
local tableToCraftingIconsFunc = EID.tableToCraftingIconsMerged
if EID.Config["BagOfCraftingDisplayIcons"] then tableToCraftingIconsFunc = EID.tableToCraftingIconsFull end
- -- Pickups Only / No Recipes Mode display
- if EID.Config["BagOfCraftingDisplayMode"] == "Pickups Only" then
+ -- Pickups Only / Itempool Percentages Mode display
+ if EID.Config["BagOfCraftingDisplayRecipesMode"] == "Pickups Only" then
EID:appendToDescription(customDescObj, getHotkeyString())
EID:appendToDescription(customDescObj, getFloorItemsString(false, roomItems))
EID:addDescriptionToPrint(customDescObj)
return true
- elseif EID.Config["BagOfCraftingDisplayMode"] == "No Recipes" then
+ elseif EID.Config["BagOfCraftingDisplayRecipesMode"] == "Itempool Percentages" then
if not EID.RefreshBagTextbox and prevDesc ~= "" and not EID.OptionChanged then
EID:appendToDescription(customDescObj, prevDesc)
EID:addDescriptionToPrint(customDescObj)